@@ -48,12 +48,9 @@ class Accumulator(object):
 
     def push(self, data):
         if not self._isValueHolderContained:
-            if isinstance(self._dependency, str):
-                if self._dependency in data:
-                    return data[self._dependency]
-                else:
-                    return None
-            elif hasattr(self._dependency, '__iter__'):
+            try:
+                return data[self._dependency]
+            except (TypeError, KeyError) as _:
                 try:
                     return tuple(data[p] for p in self._dependency)
                 except KeyError:
@@ -306,6 +303,16 @@ class GeOperatorValueHolder(ArithmeticValueHolder):
         super(GeOperatorValueHolder, self).__init__(left, right, operator.ge)
 
 
+class EqOperatorValueHolder(ArithmeticValueHolder):
+    def __init__(self, left, right):
+        super(EqOperatorValueHolder, self).__init__(left, right, operator.eq)
+
+
+class NeOperatorValueHolder(ArithmeticValueHolder):
+    def __init__(self, left, right):
+        super(NeOperatorValueHolder, self).__init__(left, right, operator.ne)
+
+
 class Identity(Accumulator):
     def __init__(self, value, n=1):
         if isinstance(value, Accumulator):
