@@ -7,6 +7,7 @@ Created on 2015-7-16
 
 import math
 import bisect
+from collections import deque
 import numpy as np
 from copy import deepcopy
 from PyFin.Math.Accumulators.IAccumulators import Accumulator
@@ -29,9 +30,8 @@ class StatefulValueHolder(Accumulator):
         self._returnSize = 1
         self._window = window
         self._containerSize = window
-        self._con = []
+        self._con = deque()
         self._isFull = 0
-        self._start = 0
 
     @property
     def isFull(self):
@@ -42,21 +42,19 @@ class StatefulValueHolder(Accumulator):
         return len(self._con)
 
     def _dumpOneValue(self, value):
-        if not hasattr(value, '__iter__'):
-            popout = np.nan
-        else:
-            popout = np.array([np.nan] * len(value))
 
-        if self.isFull:
-            # use list as circular queue
-            popout = self._con[self._start]
-            self._con[self._start] = value
-            self._start = (self._start + 1) % self._containerSize
-        elif len(self._con) + 1 == self._containerSize:
+        if self._isFull:
             self._con.append(value)
-            self._isFull = 1
+            popout = self._con.popleft()
         else:
+            try:
+                popout = np.array([np.nan] * len(value))
+            except TypeError:
+                popout = np.nan
+
             self._con.append(value)
+            if len(self._con) == self._containerSize:
+                self._isFull = 1
         return popout
 
 
@@ -93,13 +91,13 @@ class SortedValueHolder(SingleValuedValueHolder):
         value = super(SortedValueHolder, self).push(data)
         if value is None:
             return
-        if self.isFull:
+        if self._isFull:
             popout = self._dumpOneValue(value)
             delPos = bisect.bisect_left(self._sortedArray, popout)
             del self._sortedArray[delPos]
             bisect.insort_left(self._sortedArray, value)
         else:
-            _ = self._dumpOneValue(value)
+            self._dumpOneValue(value)
             bisect.insort_left(self._sortedArray, value)
 
 
@@ -124,6 +122,7 @@ class MovingMinimum(SortedValueHolder):
         else:
             return np.nan
 
+
 class MovingSum(SingleValuedValueHolder):
     def __init__(self, window, dependency='x'):
         super(MovingSum, self).__init__(window, dependency)
@@ -342,13 +341,8 @@ class MovingHistoricalWindow(StatefulValueHolder):
         length = self.size
         if item >= length:
             raise ValueError("index {0} is out of the bound of the historical current length {1}".format(item, length))
-        if self._start:
-            recentPoint = self._start - 1
-        else:
-            recentPoint = self._start + length - 1
 
-        offsetPoint = (recentPoint - item + length) % length
-        return self._con[offsetPoint]
+        return self._con[length - 1 - item]
 
     def result(self):
         return [self.__getitem__(i) for i in range(self.size)]
